@@ -3,7 +3,7 @@
 
 # maybe this module should be broken up into multiple files, or maybe not ...
 
-UA = "diffengine/0.0.38 (+https://github.com/docnow/diffengine)"
+UA = "diffengine/0.0.40 (+https://github.com/docnow/diffengine)"
 
 import os
 import re
@@ -139,7 +139,7 @@ class Entry(BaseModel):
         time.sleep(1)
 
         # fetch the current readability-ized content for the page
-        logging.debug("checking %s", self.url)
+        logging.info("checking %s", self.url)
         try:
             resp = _get(self.url)
         except Exception as e:
@@ -171,9 +171,8 @@ class Entry(BaseModel):
         # new version if it looks different, or is brand new (no old version)
         new = None
 
-        # reapply _normal to what is stored in case normalization rules
-        # change over time
-        if not old or old.title != title or _normal(old.summary) != summary:
+        # reapply _fingerprint to what is stored in case the method changes
+        if not old or old.title != title or not _equal(old.summary, summary):
             new = EntryVersion.create(
                 title=title,
                 url=canonical_url,
@@ -504,6 +503,14 @@ def _normal(s):
     s = s.strip()
     return s
 
+def _equal(s1, s2):
+    return _fingerprint(s1) == _fingerprint(s2)
+
+def _fingerprint(s):
+    s = bleach.clean(s, tags=[], strip=True)
+    s = re.sub(r'\s+', '', s, flags=re.MULTILINE)
+    return s
+
 def _remove_utm(url):
     u = urlparse(url)
     q = parse_qs(u.query, keep_blank_values=True)
